@@ -1,5 +1,5 @@
 package Riji;
-use 5.010;
+use feature ':5.10';
 use strict;
 use warnings;
 use Puncheur::Lite;
@@ -8,7 +8,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-use version 0.77; our $VERSION = version->declare("v1.1.0");
+use version 0.77; our $VERSION = version->declare("v1.1.1");
 
 __PACKAGE__->setting(
     handle_static => 1,
